
JButton = {

	/**
	 * Инициализация JButton.
	 * Навешиваются основные события и их обработчики.
	 * @param pattern jQuery-object, #id-эелемента или пустой
	 */
	init: function(pattern)
	{
		var el = null;

		if(typeof pattern == "string" && pattern.indexOf(".") == 0)
		{
			el = jQuery(pattern);
		}
		else
		{
			return;
		}

		el.each(function(){jQuery(this).data('disabled', false)})
			.bind({
				"click": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					return true;
				},
				"mouseenter": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.addClass('hover');
					return true;
				},
				"mouseleave": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.removeClass('hover pressed');
					return true;
				},
				"mousedown": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.addClass('pressed');
					return true;
				},
				"mouseup": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.removeClass('pressed');
					return true;
				}
			});
		el = null;
	}
}

JTextField = {
	init: function(parent)
	{
		var el = null;

		if(typeof parent == "object")
		{
			el = parent.find(".JTextField input");
		}
		else if(typeof parent == "string")
		{
			el = jQuery(parent).find(".JTextField input");
		}
		else
		{
			el = jQuery(".JTextField input");
		}

		el.each(function(){jQuery(this).parents('.JTextField').data('disabled', false)})
			.bind({
				"focus": function(event){
					var self = jQuery(this).parents('.JTextField');
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.addClass('focus');
					return true;
				},
				"blur": function(event){
					var self = jQuery(this).parents('.JTextField');
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.removeClass('focus');
					return true;
				}
			});
		el = null;
	}
}

JRadioButton = {

	/**
	 * Инициализация JRadioButton.
	 * Навешиваются основные события и их обработчики.
	 * @param parent jQuery-object, #id-эелемента или пустой
	 */
	init: function(parent)
	{
		var el;

		if(typeof parent == "object")
		{
			el = parent.find(".JRadioButton");
		}
		else if(typeof parent == "string")
		{
			el = jQuery(parent).find(".JRadioButton");
		}
		else
		{
			el = jQuery(".JRadioButton");
		}

		el.each(function(){jQuery(this).data('disabled', false)})
			.bind({
				"click.JRadioButton": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					JRadioButton.change(self);
					return true;
				},
				"mouseenter.JRadioButton": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.addClass('hover');
					return true;
				},
				"mouseleave.JRadioButton": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.removeClass('hover pressed');
					return true;
				},
				"mousedown.JRadioButton": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.addClass('pressed');
					return true;
				},
				"mouseup.JRadioButton": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.removeClass('pressed');
					return true;
				}
			});
			el = null;
	},

	/* Связка JRadioButton с input */
	change: function(el)
	{
		var input = el.find("input").eq(0);
		var name = input.prop("name");
		/* Если элемент уже выбран, то ничего не делаем */
		var checked = input.prop('checked');if(checked) return;
		/* Убираем у всех элементов JRadioButton с одинаковым именем класс 'checked' */
		jQuery('.JRadioButton input').each(function()
			{
				var self = jQuery(this);
				if(self.prop('name') == name)
				{
					self.prop('checked', false).parent().removeClass('checked');
				}
			}
		);
		/* Устанавливаем параметр признак 'checked' */
		el.addClass('checked');
		input.prop('checked', true);
		input = null;
	},

	/* Связка input с JRadioButton */
	visualChange: function(input, checked)
	{
		if(typeof checked == "undefined")
		{
			checked = input.prop('checked');
		}
		var name = input.prop("name");
		jQuery('.JRadioButton input').each(function()
			{
				var self = jQuery(this);
				if(self.prop('name') == name)
				{
					self.prop('checked', false).parent().removeClass('checked');
				}
			}
		);
		var el = input.parent();
		if(checked)
			el.addClass('checked');
		else
			el.removeClass('checked');
		input.prop('checked', checked);
		el = null;
	},

	checked: function(input)
	{
		var checked = input.prop('checked');
		return checked? true : false;
	}
}

JCheckBox = {

	init: function(parent)
	{
		var el;

		if(typeof parent == "object")
		{
			el = parent.find(".JCheckBox");
		}
		else if(typeof parent == "string")
		{
			el = jQuery(parent).find(".JCheckBox");
		}
		else
		{
			el = jQuery(".JCheckBox");
		}

		el.each(function(){jQuery(this).data('disabled', false)})
			.bind({
				"click.JCheckBox": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					JCheckBox.change(self)
					return true;
				},
				"mouseenter.JCheckBox": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.addClass('hover');
					return true;
				},
				"mouseleave.JCheckBox": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.removeClass('hover pressed');
					return true;
				},
				"mousedown.JCheckBox": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.addClass('pressed');
					return true;
				},
				"mouseup.JCheckBox": function(event){
					var self = jQuery(this);
					var disabled = self.data('disabled');
					if(disabled)
					{
						event.stopImmediatePropagation();
						return false;
					}
					self.removeClass('pressed');
					return true;
				}
			});
			el = null;
	},

	/* Связка JCheckBox с input */
	change: function(el)
	{
		var input = el.find("input").eq(0);
		var checked = input.prop('checked');
		if(checked)
		{
			el.removeClass('checked');
		}
		else
		{
			el.addClass('checked');
		}
		input.prop('checked', !checked);
		input = null;
	},

	/* Связка input с JCheckBox */
	visualChange: function(input, checked)
	{
		var el = input.parent(".JCheckBox");
		if(typeof checked != undefined)
		{
			input.prop('checked', checked);
		}
		else
		{
			checked = input.prop('checked');
		}
		if(checked)
		{
			el.addClass('checked');
		}
		else
		{
			el.removeClass('checked');
		}
		el = null;
	},

	disabled: function(input)
	{
		var el = input.parent(".JCheckBox");
		if(el.disabled) el.disabled();
		else
		{
			var disabled = el.data('disabled');
			if(typeof disabled == "undefined")
			{
				disabled = false;
				el.data('disabled', disabled);
			}
			if(!disabled)
			{
				el.data('disabled', !disabled);
				el.removeClass("hover pressed focus");
				el.addClass("disabled");
			}
		}
		el = null;
	},

	isDisabled: function(input)
	{
		var el = input.parent(".JCheckBox");
		return el.data('disabled');
	},

	enable: function(input)
	{
		var el = input.parent(".JCheckBox");
		el.enable();
		el = null;
	},

	checked: function(input)
	{
		var checked = input.prop('checked');
		return checked? true : false;
	}
}

function JDropDownButton(name)
{
	this._name = name;
	this._items = name + "_items";

	this.init = function init()
	{
		var el = jQuery("#" + this._name).bind("click", function(){
			var btn = window[jQuery(this).attr("id")];
			if(btn)
			{
				btn.toogle();
			}
			btn = null;
		});
		var items = jQuery("#" + this._items);
		var offset = el.offset();
		var height = el.height();
		var width = el.outerWidth(true);
		items.css({"display": "none", "position": "absolute", "left": offset.left, "top": height + offset.top, "min-width": width})
			.detach().appendTo("body")
			.mouseleave(function(){jQuery(this).hide();});
		items.find("li").hover(function(e){jQuery(this).addClass("hover");}, function(e){jQuery(this).removeClass("hover");});
		el = null;
	}

	this._closeAll = function()
	{
		var itemsId = this._items;
		jQuery("." + JDropDownButton.settings._itemsClass).each(
			function(){
				var self = jQuery(this);
				if(self.prop("id") != itemsId)
				{
					self.css({"display": "none"});
				}
			}
		);
	}

	this.toogle = function toogle()
	{
		var items = jQuery("#" + this._items);
		var display = items.css("display");
		if(display == "none")
		{
			items.css({"display": "block", "z-index": ++JCore._static.zIndex});
		}
		else
		{
			items.css({"display": "none"});
		}
		items = null;
		this._closeAll();
	}
}

JDropDownButton.settings = {};
JDropDownButton.settings._сlass = "JDropDownButton";
JDropDownButton.settings._itemsClass = "JDropDownButton-items";
JDropDownButton.init = function()
{
	JButton.init(".JDropDownButton");
	JButton.init(".JDropDownDialogButton");
}

/**
 * Вешаем обработчики на элементы
 */
jQuery(document).ready(function(){

	JButton.init(".JButton");
	JButton.init(".JDialogButton");
	JButton.init(".JFormButton");
	JDropDownButton.init();
	JRadioButton.init();
	JCheckBox.init();
	JTextField.init();
});